
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { AuthProvider } from "@/hooks/useAuth";
import ProtectedRoute from "@/components/ProtectedRoute";
import { lazy, Suspense } from "react";
import LoadingFallback from "./components/LoadingFallback";

// Lazy load ALL pages including Index for better code splitting
const Index = lazy(() => import("./pages/Index"));

// Lazy load non-critical pages
const ForBusinesses = lazy(() => import("./pages/ForBusinesses"));
const ForConsultants = lazy(() => import("./pages/ForConsultants"));
const HowItWorks = lazy(() => import("./pages/HowItWorks"));
const About = lazy(() => import("./pages/About"));
const FindConsultants = lazy(() => import("./pages/FindConsultants"));
const JoinConsultants = lazy(() => import("./pages/JoinConsultants"));
const AdminDashboard = lazy(() => import("./pages/AdminDashboard"));
const AdminLogin = lazy(() => import("./pages/AdminLogin"));
const AdminSetupPage = lazy(() => import("./pages/AdminSetup"));
const Auth = lazy(() => import("./pages/Auth"));
const AICaseStudies = lazy(() => import("./pages/AICaseStudies"));
const ChoosePartner = lazy(() => import("./pages/ChoosePartner"));
const Blog = lazy(() => import("./pages/Blog"));
const SmallBusinessAI = lazy(() => import("./pages/SmallBusinessAI"));
const MarketingAgencyAI = lazy(() => import("./pages/MarketingAgencyAI"));

const queryClient = new QueryClient();

const App = () => (
  <QueryClientProvider client={queryClient}>
    <TooltipProvider>
      <Toaster />
      <Sonner />
      <AuthProvider>
        <BrowserRouter>
          <Routes>
            <Route 
              path="/" 
              element={
                <Suspense fallback={<LoadingFallback size="lg" />}>
                  <Index />
                </Suspense>
              } 
            />
              <Route 
                path="/for-businesses" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <ForBusinesses />
                  </Suspense>
                } 
              />
              <Route 
                path="/for-consultants" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <ForConsultants />
                  </Suspense>
                } 
              />
              <Route 
                path="/how-it-works" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <HowItWorks />
                  </Suspense>
                } 
              />
              <Route 
                path="/about" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <About />
                  </Suspense>
                } 
              />
              <Route 
                path="/find-consultants" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <FindConsultants />
                  </Suspense>
                } 
              />
              <Route 
                path="/join-consultants" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <JoinConsultants />
                  </Suspense>
                } 
              />
              <Route 
                path="/ai-case-studies" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <AICaseStudies />
                  </Suspense>
                } 
              />
              <Route 
                path="/blog" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <Blog />
                  </Suspense>
                } 
              />
              <Route 
                path="/small-business-ai" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <SmallBusinessAI />
                  </Suspense>
                } 
              />
              <Route 
                path="/marketing-agency-ai" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <MarketingAgencyAI />
                  </Suspense>
                } 
              />
              <Route 
                path="/choose-partner" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <ChoosePartner />
                  </Suspense>
                } 
              />
              <Route 
                path="/auth" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <Auth />
                  </Suspense>
                } 
              />
              <Route 
                path="/admin/login" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <AdminLogin />
                  </Suspense>
                } 
              />
              <Route 
                path="/admin/setup" 
                element={
                  <Suspense fallback={<LoadingFallback />}>
                    <AdminSetupPage />
                  </Suspense>
                } 
              />
              <Route 
                path="/admin" 
                element={
                  <ProtectedRoute requiredRole="admin">
                    <Suspense fallback={<LoadingFallback />}>
                      <AdminDashboard />
                    </Suspense>
                  </ProtectedRoute>
                } 
              />
              <Route 
                path="/admin/dashboard" 
                element={
                  <ProtectedRoute requiredRole="admin">
                    <Suspense fallback={<LoadingFallback />}>
                      <AdminDashboard />
                    </Suspense>
                  </ProtectedRoute>
                } 
              />
            </Routes>
        </BrowserRouter>
      </AuthProvider>
    </TooltipProvider>
  </QueryClientProvider>
);

export default App;
